@@ -9,11 +9,6 @@
      (ft-set-sslconn! #t)
      (ft-set-server! "talk.google.com"))
 
-(add-hook! ft-login-hook
-	   (lambda (status)
-	     (if status
-		 (ft-set-status-msg! 
-		  "i use freetalk http://freetalk.nongnu.org"))))
 
 
 
