@@ -16,10 +16,8 @@
 ;;; along with this program; if not, write to the Free Software
 ;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
 
-(if (= (system "beep -f 1 -l 0 >> /dev/null 2>&1") 0)
-    (define (beep-proc timestamp from msg)
-      (system "beep -f 600 -l 10; beep -f 800 -l 10; beep -f 200 -l 10&"))
-    (define (beep-proc timestamp from msg)
-      (ft-beep 200 20)))
+(define (receive-beep timestamp from msg)
+  "beep on receiving message"
+  (system "beep -f 600 -l 10; beep -f 800 -l 10; beep -f 200 -l 10&"))
 
-(add-hook! ft-message-receive-hook beep-proc)
+(add-hook! ft-message-receive-hook receive-beep)
